@@ -12,6 +12,16 @@ from .exceptions import CatchedException, InvalidTask
 from .action import create_action, PythonAction
 
 
+def first_line(doc):
+    """extract first non-blank line from text, to extract docstring title"""
+    if doc is not None:
+        for line in doc.splitlines():
+            striped = line.strip()
+            if striped:
+                return striped
+    return ''
+
+
 class Task(object):
     """Task
 
@@ -177,9 +187,11 @@ class Task(object):
                 args = list(item[1]) if len(item)>1 else []
                 kwargs = item[2] if len(item)>2 else {}
                 uptodate.append((call, args, kwargs))
+            elif isinstance(item, six.string_types):
+                uptodate.append((item, [], {}))
             else:
                 msg = ("%s. task invalid 'uptodate' item '%r'. " +
-                       "Must be bool, None, callable or tuple " +
+                       "Must be bool, None, str, callable or tuple " +
                        "(callable, args, kwargs).")
                 raise InvalidTask(msg % (self.name, item))
         return uptodate
@@ -258,13 +270,7 @@ class Task(object):
     def _init_doc(doc):
         """process task "doc" attribute"""
         # store just first non-empty line as documentation string
-        if doc is not None:
-            for line in doc.splitlines():
-                striped = line.strip()
-                if striped:
-                    return striped
-        return ''
-
+        return first_line(doc)
 
     @staticmethod
     def check_attr(task, attr, value, valid):
